==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-6c.js <==
dispMUA.arDispMUAAllocation["l"] =
{
  "lonely cat games profimail" : [ "lonelycatgames.png" , "http://www.lonelycatgames.com/?app=profimail" ] ,
  "lunaphone.com auto-mailer" : [ "lunaphone.png" , "http://www.lunaphone.com/" ] ,
  "lotus notes release 7" : [ "lotus_notes7.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes release 6" : [ "lotus_notes6.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes release 5" : [ "lotus_notes5.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes build v8" : [ "lotus_notes8.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes build v7" : [ "lotus_notes7.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lursoft mail engine" : [ "lursoft.png" ] ,
  "linuxquestions.org" : [ "linuxquestions_org.png" , "http://www.linuxquestions.org/" ] ,
  "lasso professional" : [ "lasso.png" ] ,
  "lycos web mailer" : [ "lycos_mail.png" ] ,
  "loadmail smtp" : [ "loadmail.png" ] ,
  "lotus domino" : [ "lotus_domino6.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes" : [ "lotus_notes.png" , "http://www.ibm.com/software/lotus/" ] ,
  "libwww-perl" : [ "libwww-perl.png" , "http://linpro.no/lwp/" ] ,
  "laszlo mail" : [ "laszlomail.png" ] ,
  "lycosmail" : [ "lycos.png" ] ,
  "lq mailer" : [ "linuxquestions_org.png" , "http://www.linuxquestions.org/" ] ,
  "logicmail" : [ "logicmail.png" , "http://www.logicprobe.org/proj/logicmail" ] ,
  "log_mail" : [ "pear.png" ] ,
  "locamail" : [ "locamail.png" ] ,
  "listserv" : [ "listserv.png" ] ,
  "listmail" : [ "listmail.png" , "http://www.listmailpro.com/" ] ,
  "listrak" : [ "listrak.png" ] ,
  "lyris" : [ "lyris.png" , "http://www.lyris.com/" ] ,
  "lucy" : [ "lucy.png" , "http://www.geniegate.com/other/lucy/" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-6c.js <==
dispMUA.arDispMUAAllocation["l"] =
{
  "lonely cat games profimail" : [ "lcg-profimail.png" , "http://www.lonelycatgames.com/?app=profimail" ] ,
  "lunaphone.com auto-mailer" : [ "lunaphone.png" , "http://www.lunaphone.com/" ] ,
  "lotus notes release 8" : [ "lotus_notes8.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes release 7" : [ "lotus_notes7.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes release 6" : [ "lotus_notes6.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes release 5" : [ "lotus_notes5.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes build v8" : [ "lotus_notes8.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes build v7" : [ "lotus_notes7.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lursoft mail engine" : [ "lursoft.png" ] ,
  "linuxquestions.org" : [ "linuxquestions_org.png" , "http://www.linuxquestions.org/" ] ,
  "lasso professional" : [ "lasso.png" ] ,
  "lycos web mailer" : [ "lycos_mail.png" ] ,
  "lussumo mailer" : [ "lussumo.png" , "http://lussumo.com/" ] ,
  "loadmail smtp" : [ "loadmail.png" ] ,
  "l-soft hdmail" : [ "hdmail.png" , "http://www.lsoft.com/PRODUCTS/hdmail.asp" ] ,
  "lotus domino" : [ "lotus_domino6.png" , "http://www.ibm.com/software/lotus/" ] ,
  "lotus notes" : [ "lotus_notes.png" , "http://www.ibm.com/software/lotus/" ] ,
  "libwww-perl" : [ "libwww-perl.png" , "http://linpro.no/lwp/" ] ,
  "laszlo mail" : [ "laszlomail.png" ] ,
  "lycosmail" : [ "lycos.png" ] ,
  "lq mailer" : [ "linuxquestions_org.png" , "http://www.linuxquestions.org/" ] ,
  "logicmail" : [ "logicmail.png" , "http://www.logicprobe.org/proj/logicmail" ] ,
  "log_mail" : [ "pear.png" ] ,
  "locamail" : [ "locamail.png" ] ,
  "listserv" : [ "listserv.png" ] ,
  "listmail" : [ "listmail.png" , "http://www.listmailpro.com/" ] ,
  "lobocom" : [ "lobocom.png" , "http://webmail.lobocom.es/" ] ,
  "listrak" : [ "listrak.png" ] ,
  "lyris" : [ "lyris.png" , "http://www.lyris.com/" ] ,
  "lynx" : [ "lynx.png" , "http://lynx.isc.org/" ] ,
  "lucy" : [ "lucy.png" , "http://www.geniegate.com/other/lucy/" ] ,
}
